#include <stdio.h>
#include <string.h>

const long MAX_LONGNUM_LEN = 50;

template<class T>
T Max(T a, T b)
{
	return (a > b) ? a : b;
}

class longnum
{
	long digits[MAX_LONGNUM_LEN];
	long len;

	void Normalize(void)
	{
		long iDigit;
		for(iDigit = 0; iDigit < len - 1; ++iDigit)
			if(digits[iDigit] > 9)
			{
				digits[iDigit + 1] += digits[iDigit] / 10;
				digits[iDigit] %= 10;
			}
		for(;len && !digits[len - 1]; --len);
	}

	longnum(const longnum &number1, const longnum& number2, char operation)
	{
		long iDigit;
		if(operation == '+')
		{
			len = Max(number1.len, number2.len) + 1;
			if(len >= MAX_LONGNUM_LEN)fputs("Overflow", stderr);
			memset(digits, 0, len * sizeof(digits[0]));
			memcpy(digits, number1.digits, number1.len * sizeof(digits[0]));
			for(iDigit = 0; iDigit < number2.len; ++iDigit)
				digits[iDigit] += number2.digits[iDigit];
		}
		Normalize();
	}
public:
	longnum(void)
	{
		len = 0;
	}

	longnum(unsigned long number)
	{
		len = 0;
		for(len = 0; number; ++len, number /= 10)
			digits[len] = number % 10;
	}

	longnum(const longnum& number)
	{
		len = number.len;
		memcpy(digits, number.digits, len * sizeof(digits[0]));
	}

	const longnum& operator=(const longnum& number)
	{
		len = number.len;
		memcpy(digits, number.digits, len * sizeof(digits[0]));
		return *this;
	}

	void Print(void)const
	{
		long iDigit;
		if(! len)putchar('0');
		for(iDigit = len; iDigit; --iDigit)putchar('0' + digits[iDigit - 1]);
	}

	longnum operator + (const longnum &number)const
	{
		return longnum(*this, number, '+');
	}
};

const long FIB_COUNT = 51;

longnum fib[FIB_COUNT + 1];

int main(void)
{
#ifndef ONLINE_JUDGE
	freopen("input.txt", "r", stdin);
	freopen("output.txt", "w", stdout);
#endif

	fib[0] = fib[1] = 1;
	int iFib;
	for(iFib = 2; iFib <= FIB_COUNT; ++iFib)
		fib[iFib] = fib[iFib - 1] + fib[iFib -2];

	long cTests, iTest, length;
	scanf("%ld", &cTests);
	for(iTest = 0; iTest < cTests; ++iTest)
	{
		printf("Scenario #%ld:\n", iTest + 1);
		scanf("%ld", &length);
		fib[length + 1].Print();
		putchar('\n');
		putchar('\n');
	}

#ifndef ONLINE_JUDGE
	fclose(stdin);
	fclose(stdout);
#endif

	return 0;
}